==> v1.18.1.tar.gz: detekt-1.18.1/detekt-rules-style/src/test/kotlin/io/gitlab/arturbosch/detekt/rules/style/optional/MandatoryBracesIfStatementsSpec.kt <==
package io.gitlab.arturbosch.detekt.rules.style.optional

import io.gitlab.arturbosch.detekt.api.Config
import io.gitlab.arturbosch.detekt.test.assertThat
import io.gitlab.arturbosch.detekt.test.compileAndLint
import org.spekframework.spek2.Spek
import org.spekframework.spek2.style.specification.describe

class MandatoryBracesIfStatementsSpec : Spek({
    val subject by memoized { MandatoryBracesIfStatements(Config.empty) }

    describe("if statements which should have braces") {

        it("reports a simple if") {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true)
                    println()
            }
            """
            )

            assertThat(findings).hasSize(1)
            assertThat(findings).hasTextLocations(32 to 41)
        }

        it("reports a simple if with a single statement in multiple lines") {
            val findings = subject.compileAndLint(
                """
                fun f() {
                	if (true) 50
                        .toString()
                }
            """
            )

            assertThat(findings).hasSize(1)
        }

        it("reports if-else with a single statement in multiple lines") {
            val findings = subject.compileAndLint(
                """
                fun f() {
                	if (true) 50
                        .toString() else 50
                        .toString()
                }
            """
            )

            assertThat(findings).hasSize(2)
        }

        it("reports if-else") {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true)
                    println()
                else
                    println()
            }
            """
            )

            assertThat(findings).hasSize(2)
            assertThat(findings).hasTextLocations(32 to 41, 59 to 68)
        }

        it("reports if-else with else-if") {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true)
                    println()
                else if (false)
                    println()
                else
                    println()
            }
            """
            )

            assertThat(findings).hasSize(3)
            assertThat(findings).hasTextLocations(32 to 41, 70 to 79, 97 to 106)
        }

        it("reports if with braces but else without") {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true) {
                    println()
                } else
                    println()
            }
            """
            )

            assertThat(findings).hasSize(1)
            assertThat(findings).hasTextLocations(63 to 72)
        }

        it("reports else with braces but if without") {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true)
                    println()
                else {
                    println()
                }
            }
            """
            )

            assertThat(findings).hasSize(1)
            assertThat(findings).hasTextLocations(32 to 41)
        }

        it("reports else in new line") {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true) println()
                else println()
            }
            """
            )

            assertThat(findings).hasSize(1)
            assertThat(findings).hasTextLocations(24 to 33)
        }

        it("reports only else body on new line") {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true) println() else
                    println()
            }
            """
            )

            assertThat(findings).hasSize(1)
            assertThat(findings).hasTextLocations(47 to 56)
        }
    }

    describe("if statements with braces") {

        it("does not report if statements with braces") {
            val code = """
                fun f() {
                	if (true) {
                		println()
                	}
                	if (true)
                	{
                		println()
                	}
                	if (true) { println() }
                }
            """
            assertThat(subject.compileAndLint(code)).isEmpty()
        }
    }

    describe("single-line if statements which don't need braces") {

        it("does not report single-line if statements") {
            val code = """
                fun f() {
                	if (true) println()
                	if (true) println() else println()
                	if (true) println() else if (false) println() else println()
                }
            """
            assertThat(subject.compileAndLint(code)).isEmpty()
        }
    }

    describe("multi-line when following an else statement without requiring braces") {

        it("does not report multi-line when") {
            val code = """
                fun f(i: Int) {
                	if (true) {
                        println()
                    } else when(i) {
                        1 -> println(1)
                        else -> println()
                    }
                }
            """
            assertThat(subject.compileAndLint(code)).isEmpty()
        }
    }
})

==> v1.21.0.tar.gz: detekt-1.21.0/detekt-rules-style/src/test/kotlin/io/gitlab/arturbosch/detekt/rules/style/optional/MandatoryBracesIfStatementsSpec.kt <==
package io.gitlab.arturbosch.detekt.rules.style.optional

import io.gitlab.arturbosch.detekt.api.Config
import io.gitlab.arturbosch.detekt.test.assertThat
import io.gitlab.arturbosch.detekt.test.compileAndLint
import org.junit.jupiter.api.Nested
import org.junit.jupiter.api.Test

class MandatoryBracesIfStatementsSpec {
    val subject = MandatoryBracesIfStatements(Config.empty)

    @Nested
    inner class `if statements which should have braces` {

        @Test
        fun `reports a simple if`() {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true)
                    println()
            }
                """
            )

            assertThat(findings).hasSize(1)
            assertThat(findings).hasTextLocations(32 to 41)
        }

        @Test
        fun `reports a simple if with a single statement in multiple lines`() {
            val findings = subject.compileAndLint(
                """
                fun f() {
                	if (true) 50
                        .toString()
                }
                """
            )

            assertThat(findings).hasSize(1)
        }

        @Test
        fun `reports if-else with a single statement in multiple lines`() {
            val findings = subject.compileAndLint(
                """
                fun f() {
                	if (true) 50
                        .toString() else 50
                        .toString()
                }
                """
            )

            assertThat(findings).hasSize(2)
        }

        @Test
        fun `reports if-else`() {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true)
                    println()
                else
                    println()
            }
                """
            )

            assertThat(findings).hasSize(2)
            assertThat(findings).hasTextLocations(32 to 41, 59 to 68)
        }

        @Test
        fun `reports if-else with else-if`() {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true)
                    println()
                else if (false)
                    println()
                else
                    println()
            }
                """
            )

            assertThat(findings).hasSize(3)
            assertThat(findings).hasTextLocations(32 to 41, 70 to 79, 97 to 106)
        }

        @Test
        fun `reports if with braces but else without`() {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true) {
                    println()
                } else
                    println()
            }
                """
            )

            assertThat(findings).hasSize(1)
            assertThat(findings).hasTextLocations(63 to 72)
        }

        @Test
        fun `reports else with braces but if without`() {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true)
                    println()
                else {
                    println()
                }
            }
                """
            )

            assertThat(findings).hasSize(1)
            assertThat(findings).hasTextLocations(32 to 41)
        }

        @Test
        fun `reports else in new line`() {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true) println()
                else println()
            }
                """
            )

            assertThat(findings).hasSize(1)
            assertThat(findings).hasTextLocations(24 to 33)
        }

        @Test
        fun `reports only else body on new line`() {
            val findings = subject.compileAndLint(
                """
            fun f() {
                if (true) println() else
                    println()
            }
                """
            )

            assertThat(findings).hasSize(1)
            assertThat(findings).hasTextLocations(47 to 56)
        }
    }

    @Nested
    inner class `if statements with braces` {

        @Test
        fun `does not report if statements with braces`() {
            val code = """
                fun f() {
                	if (true) {
                		println()
                	}
                	if (true)
                	{
                		println()
                	}
                	if (true) { println() }
                }
            """
            assertThat(subject.compileAndLint(code)).isEmpty()
        }
    }

    @Nested
    inner class `single-line if statements which don't need braces` {

        @Test
        fun `does not report single-line if statements`() {
            val code = """
                fun f() {
                	if (true) println()
                	if (true) println() else println()
                	if (true) println() else if (false) println() else println()
                }
            """
            assertThat(subject.compileAndLint(code)).isEmpty()
        }
    }

    @Nested
    inner class `multi-line when following an else statement without requiring braces` {

        @Test
        fun `does not report multi-line when`() {
            val code = """
                fun f(i: Int) {
                	if (true) {
                        println()
                    } else when(i) {
                        1 -> println(1)
                        else -> println()
                    }
                }
            """
            assertThat(subject.compileAndLint(code)).isEmpty()
        }
    }
}
